#!/usr/bin/env python

from setuptools import setup, find_packages

setup(
    name='gust',
    version='1.0.1',
    description='Gust shim for Python.',
    author='Sam Gammon',
    author_email='sam.g@cookies.co',
    url='https://github.com/sgammon/GUST',
    packages=["gust", "gust.core"],
    requires=['protobuf'],
    install_requires=['protobuf>=3.13.0']
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gust/core/datamodel.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gust/core/datamodel.proto',
  package='core',
  syntax='proto3',
  serialized_options=b'\n\020tools.elide.coreB\tDatamodelH\001P\001Z5github.com/elide-tools/elide/core/datamodel;datamodel\330\001\001\370\001\001\242\002\003ELD\252\002\nElide.Core\272\002\005Elide\302\002\003ELD\312\002\005Elide\352\002\013Elide::Core',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19gust/core/datamodel.proto\x12\x04\x63ore\x1a google/protobuf/descriptor.proto\"o\n\x10\x44\x61tapointOptions\x12$\n\nvisibility\x18\x01 \x01(\x0e\x32\x10.core.Visibility\x12\x10\n\x08required\x18\x02 \x01(\x08\x12\x10\n\x08\x63oncrete\x18\x03 \x01(\x08\x12\x11\n\tephemeral\x18\x04 \x01(\x08\"V\n\x12PersistenceOptions\x12\"\n\x04mode\x18\x01 \x01(\x0e\x32\x14.core.CollectionMode\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0e\n\x06parent\x18\x03 \x01(\t\"1\n\x0cTableOptions\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"f\n\x11SubmessageOptions\x12\"\n\x04mode\x18\x01 \x01(\x0e\x32\x14.core.CollectionMode\x12\x10\n\x08\x63oncrete\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\r\n\x05\x65mbed\x18\x04 \x01(\x08\"\xf1\x01\n\x17\x46ieldPersistenceOptions\x12\x1d\n\x04type\x18\x01 \x01(\x0e\x32\x0f.core.FieldType\x12\x0f\n\x07summary\x18\x02 \x01(\t\x12\x14\n\x0cstamp_update\x18\x03 \x01(\x08\x12\x14\n\x0cstamp_create\x18\x04 \x01(\x08\x12\x11\n\tread_only\x18\x05 \x01(\x08\x12\x11\n\timmutable\x18\x06 \x01(\x08\x12\x10\n\x08\x65xplicit\x18\x07 \x01(\x08\x12)\n\nvisibility\x18\x08 \x01(\x0e\x32\x15.core.FieldVisibility\x12\x17\n\x0b\x64\x65scription\x18\t \x01(\tB\x02\x18\x01\"D\n\x11TableFieldOptions\x12\x0f\n\x07require\x18\x01 \x01(\x08\x12\x0e\n\x06ignore\x18\x02 \x01(\x08\x12\x0e\n\x06\x62qtype\x18\x03 \x01(\t\"!\n\rObjectMapping\x12\x10\n\x08instance\x18\x01 \x03(\t*M\n\nVisibility\x12\n\n\x06PUBLIC\x10\x00\x12\x0b\n\x07PRIVATE\x10\x01\x12\r\n\tPROTECTED\x10\x02\x12\x0b\n\x07PACKAGE\x10\x03\x12\n\n\x06\x45XPORT\x10\x04*7\n\x0e\x43ollectionMode\x12\n\n\x06NESTED\x10\x00\x12\x0e\n\nCOLLECTION\x10\x01\x12\t\n\x05GROUP\x10\x02*i\n\tFieldType\x12\x0c\n\x08STANDARD\x10\x00\x12\x07\n\x03KEY\x10\x01\x12\x06\n\x02ID\x10\x02\x12\x08\n\x04TAGS\x10\x03\x12\t\n\x05\x46LAGS\x10\x04\x12\r\n\tREFERENCE\x10\x05\x12\r\n\tTIMESTAMP\x10\x06\x12\n\n\x06PARENT\x10\x07*K\n\rDatapointType\x12\n\n\x06OBJECT\x10\x00\x12\x0e\n\nOBJECT_KEY\x10\x01\x12\t\n\x05\x45VENT\x10\x02\x12\t\n\x05TABLE\x10\x03\x12\x08\n\x04WIRE\x10\x04*5\n\x0e\x45numeratedType\x12\x17\n\x13GENERIC_ENUMERATION\x10\x00\x12\n\n\x06\x45RRORS\x10\x01*\\\n\x0f\x46ieldVisibility\x12\x16\n\x12\x44\x45\x46\x41ULT_VISIBILITY\x10\x00\x12\x08\n\x04OPEN\x10\x01\x12\x0e\n\nAUTHORIZED\x10\x02\x12\t\n\x05OWNER\x10\x03\x12\x0c\n\x08INTERNAL\x10\x04:C\n\x04role\x12\x1f.google.protobuf.MessageOptions\x18\xf0. \x01(\x0e\x32\x13.core.DatapointType:F\n\x02\x64\x62\x12\x1f.google.protobuf.MessageOptions\x18\xf1. \x01(\x0b\x32\x18.core.PersistenceOptions:C\n\x05table\x12\x1f.google.protobuf.MessageOptions\x18\xf2. \x01(\x0b\x32\x12.core.TableOptions:B\n\x03map\x12\x1f.google.protobuf.MessageOptions\x18\xf3. \x01(\x0b\x32\x13.core.ObjectMapping:E\n\x03msg\x12\x1f.google.protobuf.MessageOptions\x18\xf4. \x01(\x0b\x32\x16.core.DatapointOptions:L\n\x05\x66ield\x12\x1d.google.protobuf.FieldOptions\x18\xd8\x36 \x01(\x0b\x32\x1d.core.FieldPersistenceOptions:G\n\x06\x63olumn\x12\x1d.google.protobuf.FieldOptions\x18\xd9\x36 \x01(\x0b\x32\x17.core.TableFieldOptions:K\n\ncollection\x12\x1d.google.protobuf.FieldOptions\x18\xda\x36 \x01(\x0b\x32\x17.core.SubmessageOptions:D\n\x04opts\x12\x1d.google.protobuf.FieldOptions\x18\xdb\x36 \x01(\x0b\x32\x16.core.DatapointOptions:1\n\x05label\x12!.google.protobuf.EnumValueOptions\x18\xc3> \x01(\t:I\n\x05value\x12!.google.protobuf.EnumValueOptions\x18\xc7> \x01(\x0b\x32\x16.core.DatapointOptions:F\n\tenum_role\x12\x1c.google.protobuf.EnumOptions\x18\xa8\x46 \x01(\x0e\x32\x14.core.EnumeratedType:J\n\x0b\x65numeration\x12\x1c.google.protobuf.EnumOptions\x18\xa9\x46 \x01(\x0b\x32\x16.core.DatapointOptionsB\x95\x01\n\x10tools.elide.coreB\tDatamodelH\x01P\x01Z5github.com/elide-tools/elide/core/datamodel;datamodel\xd8\x01\x01\xf8\x01\x01\xa2\x02\x03\x45LD\xaa\x02\nElide.Core\xba\x02\x05\x45lide\xc2\x02\x03\x45LD\xca\x02\x05\x45lide\xea\x02\x0b\x45lide::Coreb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])

_VISIBILITY = _descriptor.EnumDescriptor(
  name='Visibility',
  full_name='core.Visibility',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PUBLIC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIVATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROTECTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PACKAGE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXPORT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=774,
  serialized_end=851,
)
_sym_db.RegisterEnumDescriptor(_VISIBILITY)

Visibility = enum_type_wrapper.EnumTypeWrapper(_VISIBILITY)
_COLLECTIONMODE = _descriptor.EnumDescriptor(
  name='CollectionMode',
  full_name='core.CollectionMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NESTED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLLECTION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=853,
  serialized_end=908,
)
_sym_db.RegisterEnumDescriptor(_COLLECTIONMODE)

CollectionMode = enum_type_wrapper.EnumTypeWrapper(_COLLECTIONMODE)
_FIELDTYPE = _descriptor.EnumDescriptor(
  name='FieldType',
  full_name='core.FieldType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STANDARD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KEY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ID', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TAGS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLAGS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REFERENCE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMESTAMP', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARENT', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=910,
  serialized_end=1015,
)
_sym_db.RegisterEnumDescriptor(_FIELDTYPE)

FieldType = enum_type_wrapper.EnumTypeWrapper(_FIELDTYPE)
_DATAPOINTTYPE = _descriptor.EnumDescriptor(
  name='DatapointType',
  full_name='core.DatapointType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OBJECT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBJECT_KEY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TABLE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIRE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1017,
  serialized_end=1092,
)
_sym_db.RegisterEnumDescriptor(_DATAPOINTTYPE)

DatapointType = enum_type_wrapper.EnumTypeWrapper(_DATAPOINTTYPE)
_ENUMERATEDTYPE = _descriptor.EnumDescriptor(
  name='EnumeratedType',
  full_name='core.EnumeratedType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GENERIC_ENUMERATION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERRORS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1094,
  serialized_end=1147,
)
_sym_db.RegisterEnumDescriptor(_ENUMERATEDTYPE)

EnumeratedType = enum_type_wrapper.EnumTypeWrapper(_ENUMERATEDTYPE)
_FIELDVISIBILITY = _descriptor.EnumDescriptor(
  name='FieldVisibility',
  full_name='core.FieldVisibility',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT_VISIBILITY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTHORIZED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OWNER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1149,
  serialized_end=1241,
)
_sym_db.RegisterEnumDescriptor(_FIELDVISIBILITY)

FieldVisibility = enum_type_wrapper.EnumTypeWrapper(_FIELDVISIBILITY)
PUBLIC = 0
PRIVATE = 1
PROTECTED = 2
PACKAGE = 3
EXPORT = 4
NESTED = 0
COLLECTION = 1
GROUP = 2
STANDARD = 0
KEY = 1
ID = 2
TAGS = 3
FLAGS = 4
REFERENCE = 5
TIMESTAMP = 6
PARENT = 7
OBJECT = 0
OBJECT_KEY = 1
EVENT = 2
TABLE = 3
WIRE = 4
GENERIC_ENUMERATION = 0
ERRORS = 1
DEFAULT_VISIBILITY = 0
OPEN = 1
AUTHORIZED = 2
OWNER = 3
INTERNAL = 4

ROLE_FIELD_NUMBER = 6000
role = _descriptor.FieldDescriptor(
  name='role', full_name='core.role', index=0,
  number=6000, type=14, cpp_type=8, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DB_FIELD_NUMBER = 6001
db = _descriptor.FieldDescriptor(
  name='db', full_name='core.db', index=1,
  number=6001, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
TABLE_FIELD_NUMBER = 6002
table = _descriptor.FieldDescriptor(
  name='table', full_name='core.table', index=2,
  number=6002, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
MAP_FIELD_NUMBER = 6003
map = _descriptor.FieldDescriptor(
  name='map', full_name='core.map', index=3,
  number=6003, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
MSG_FIELD_NUMBER = 6004
msg = _descriptor.FieldDescriptor(
  name='msg', full_name='core.msg', index=4,
  number=6004, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
FIELD_FIELD_NUMBER = 7000
field = _descriptor.FieldDescriptor(
  name='field', full_name='core.field', index=5,
  number=7000, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
COLUMN_FIELD_NUMBER = 7001
column = _descriptor.FieldDescriptor(
  name='column', full_name='core.column', index=6,
  number=7001, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
COLLECTION_FIELD_NUMBER = 7002
collection = _descriptor.FieldDescriptor(
  name='collection', full_name='core.collection', index=7,
  number=7002, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTS_FIELD_NUMBER = 7003
opts = _descriptor.FieldDescriptor(
  name='opts', full_name='core.opts', index=8,
  number=7003, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
LABEL_FIELD_NUMBER = 8003
label = _descriptor.FieldDescriptor(
  name='label', full_name='core.label', index=9,
  number=8003, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
VALUE_FIELD_NUMBER = 8007
value = _descriptor.FieldDescriptor(
  name='value', full_name='core.value', index=10,
  number=8007, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ENUM_ROLE_FIELD_NUMBER = 9000
enum_role = _descriptor.FieldDescriptor(
  name='enum_role', full_name='core.enum_role', index=11,
  number=9000, type=14, cpp_type=8, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ENUMERATION_FIELD_NUMBER = 9001
enumeration = _descriptor.FieldDescriptor(
  name='enumeration', full_name='core.enumeration', index=12,
  number=9001, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)


_DATAPOINTOPTIONS = _descriptor.Descriptor(
  name='DatapointOptions',
  full_name='core.DatapointOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='visibility', full_name='core.DatapointOptions.visibility', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required', full_name='core.DatapointOptions.required', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='concrete', full_name='core.DatapointOptions.concrete', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ephemeral', full_name='core.DatapointOptions.ephemeral', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=180,
)


_PERSISTENCEOPTIONS = _descriptor.Descriptor(
  name='PersistenceOptions',
  full_name='core.PersistenceOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='core.PersistenceOptions.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='core.PersistenceOptions.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent', full_name='core.PersistenceOptions.parent', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=268,
)


_TABLEOPTIONS = _descriptor.Descriptor(
  name='TableOptions',
  full_name='core.TableOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='core.TableOptions.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='core.TableOptions.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=319,
)


_SUBMESSAGEOPTIONS = _descriptor.Descriptor(
  name='SubmessageOptions',
  full_name='core.SubmessageOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='core.SubmessageOptions.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='concrete', full_name='core.SubmessageOptions.concrete', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='core.SubmessageOptions.path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='embed', full_name='core.SubmessageOptions.embed', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=321,
  serialized_end=423,
)


_FIELDPERSISTENCEOPTIONS = _descriptor.Descriptor(
  name='FieldPersistenceOptions',
  full_name='core.FieldPersistenceOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='core.FieldPersistenceOptions.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='summary', full_name='core.FieldPersistenceOptions.summary', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stamp_update', full_name='core.FieldPersistenceOptions.stamp_update', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stamp_create', full_name='core.FieldPersistenceOptions.stamp_create', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_only', full_name='core.FieldPersistenceOptions.read_only', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='immutable', full_name='core.FieldPersistenceOptions.immutable', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='explicit', full_name='core.FieldPersistenceOptions.explicit', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visibility', full_name='core.FieldPersistenceOptions.visibility', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='core.FieldPersistenceOptions.description', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=667,
)


_TABLEFIELDOPTIONS = _descriptor.Descriptor(
  name='TableFieldOptions',
  full_name='core.TableFieldOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='require', full_name='core.TableFieldOptions.require', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore', full_name='core.TableFieldOptions.ignore', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bqtype', full_name='core.TableFieldOptions.bqtype', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=669,
  serialized_end=737,
)


_OBJECTMAPPING = _descriptor.Descriptor(
  name='ObjectMapping',
  full_name='core.ObjectMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='core.ObjectMapping.instance', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=739,
  serialized_end=772,
)

_DATAPOINTOPTIONS.fields_by_name['visibility'].enum_type = _VISIBILITY
_PERSISTENCEOPTIONS.fields_by_name['mode'].enum_type = _COLLECTIONMODE
_SUBMESSAGEOPTIONS.fields_by_name['mode'].enum_type = _COLLECTIONMODE
_FIELDPERSISTENCEOPTIONS.fields_by_name['type'].enum_type = _FIELDTYPE
_FIELDPERSISTENCEOPTIONS.fields_by_name['visibility'].enum_type = _FIELDVISIBILITY
DESCRIPTOR.message_types_by_name['DatapointOptions'] = _DATAPOINTOPTIONS
DESCRIPTOR.message_types_by_name['PersistenceOptions'] = _PERSISTENCEOPTIONS
DESCRIPTOR.message_types_by_name['TableOptions'] = _TABLEOPTIONS
DESCRIPTOR.message_types_by_name['SubmessageOptions'] = _SUBMESSAGEOPTIONS
DESCRIPTOR.message_types_by_name['FieldPersistenceOptions'] = _FIELDPERSISTENCEOPTIONS
DESCRIPTOR.message_types_by_name['TableFieldOptions'] = _TABLEFIELDOPTIONS
DESCRIPTOR.message_types_by_name['ObjectMapping'] = _OBJECTMAPPING
DESCRIPTOR.enum_types_by_name['Visibility'] = _VISIBILITY
DESCRIPTOR.enum_types_by_name['CollectionMode'] = _COLLECTIONMODE
DESCRIPTOR.enum_types_by_name['FieldType'] = _FIELDTYPE
DESCRIPTOR.enum_types_by_name['DatapointType'] = _DATAPOINTTYPE
DESCRIPTOR.enum_types_by_name['EnumeratedType'] = _ENUMERATEDTYPE
DESCRIPTOR.enum_types_by_name['FieldVisibility'] = _FIELDVISIBILITY
DESCRIPTOR.extensions_by_name['role'] = role
DESCRIPTOR.extensions_by_name['db'] = db
DESCRIPTOR.extensions_by_name['table'] = table
DESCRIPTOR.extensions_by_name['map'] = map
DESCRIPTOR.extensions_by_name['msg'] = msg
DESCRIPTOR.extensions_by_name['field'] = field
DESCRIPTOR.extensions_by_name['column'] = column
DESCRIPTOR.extensions_by_name['collection'] = collection
DESCRIPTOR.extensions_by_name['opts'] = opts
DESCRIPTOR.extensions_by_name['label'] = label
DESCRIPTOR.extensions_by_name['value'] = value
DESCRIPTOR.extensions_by_name['enum_role'] = enum_role
DESCRIPTOR.extensions_by_name['enumeration'] = enumeration
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DatapointOptions = _reflection.GeneratedProtocolMessageType('DatapointOptions', (_message.Message,), {
  'DESCRIPTOR' : _DATAPOINTOPTIONS,
  '__module__' : 'gust.core.datamodel_pb2'
  # @@protoc_insertion_point(class_scope:core.DatapointOptions)
  })
_sym_db.RegisterMessage(DatapointOptions)

PersistenceOptions = _reflection.GeneratedProtocolMessageType('PersistenceOptions', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENCEOPTIONS,
  '__module__' : 'gust.core.datamodel_pb2'
  # @@protoc_insertion_point(class_scope:core.PersistenceOptions)
  })
_sym_db.RegisterMessage(PersistenceOptions)

TableOptions = _reflection.GeneratedProtocolMessageType('TableOptions', (_message.Message,), {
  'DESCRIPTOR' : _TABLEOPTIONS,
  '__module__' : 'gust.core.datamodel_pb2'
  # @@protoc_insertion_point(class_scope:core.TableOptions)
  })
_sym_db.RegisterMessage(TableOptions)

SubmessageOptions = _reflection.GeneratedProtocolMessageType('SubmessageOptions', (_message.Message,), {
  'DESCRIPTOR' : _SUBMESSAGEOPTIONS,
  '__module__' : 'gust.core.datamodel_pb2'
  # @@protoc_insertion_point(class_scope:core.SubmessageOptions)
  })
_sym_db.RegisterMessage(SubmessageOptions)

FieldPersistenceOptions = _reflection.GeneratedProtocolMessageType('FieldPersistenceOptions', (_message.Message,), {
  'DESCRIPTOR' : _FIELDPERSISTENCEOPTIONS,
  '__module__' : 'gust.core.datamodel_pb2'
  # @@protoc_insertion_point(class_scope:core.FieldPersistenceOptions)
  })
_sym_db.RegisterMessage(FieldPersistenceOptions)

TableFieldOptions = _reflection.GeneratedProtocolMessageType('TableFieldOptions', (_message.Message,), {
  'DESCRIPTOR' : _TABLEFIELDOPTIONS,
  '__module__' : 'gust.core.datamodel_pb2'
  # @@protoc_insertion_point(class_scope:core.TableFieldOptions)
  })
_sym_db.RegisterMessage(TableFieldOptions)

ObjectMapping = _reflection.GeneratedProtocolMessageType('ObjectMapping', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTMAPPING,
  '__module__' : 'gust.core.datamodel_pb2'
  # @@protoc_insertion_point(class_scope:core.ObjectMapping)
  })
_sym_db.RegisterMessage(ObjectMapping)

role.enum_type = _DATAPOINTTYPE
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(role)
db.message_type = _PERSISTENCEOPTIONS
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(db)
table.message_type = _TABLEOPTIONS
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(table)
map.message_type = _OBJECTMAPPING
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(map)
msg.message_type = _DATAPOINTOPTIONS
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(msg)
field.message_type = _FIELDPERSISTENCEOPTIONS
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(field)
column.message_type = _TABLEFIELDOPTIONS
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(column)
collection.message_type = _SUBMESSAGEOPTIONS
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(collection)
opts.message_type = _DATAPOINTOPTIONS
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(opts)
google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(label)
value.message_type = _DATAPOINTOPTIONS
google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(value)
enum_role.enum_type = _ENUMERATEDTYPE
google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(enum_role)
enumeration.message_type = _DATAPOINTOPTIONS
google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(enumeration)

DESCRIPTOR._options = None
_FIELDPERSISTENCEOPTIONS.fields_by_name['description']._options = None
# @@protoc_insertion_point(module_scope)
